summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMalcolm Priestley2014-05-31 00:22:51 +0200
committerGreg Kroah-Hartman2014-06-20 00:56:49 +0200
commit88ec2f7e47d201a28acbbee407805234ca5ec8c9 (patch)
treec62a41bf601839ac20b130b13406841694b85390
parentstaging: vt6656: rename CARDvSetFirstNextTBTT to vnt_reset_next_tbtt (diff)
downloadkernel-qcow2-linux-88ec2f7e47d201a28acbbee407805234ca5ec8c9.tar.gz
kernel-qcow2-linux-88ec2f7e47d201a28acbbee407805234ca5ec8c9.tar.xz
kernel-qcow2-linux-88ec2f7e47d201a28acbbee407805234ca5ec8c9.zip
staging: vt6656: rename CARDvUpdateNextTBTT to vnt_update_next_tbtt
Drop card and rename to vnt_update_next_tbtt Signed-off-by: Malcolm Priestley <tvboxspy@gmail.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
-rw-r--r--drivers/staging/vt6656/card.c4
-rw-r--r--drivers/staging/vt6656/card.h3
-rw-r--r--drivers/staging/vt6656/wmgr.c4
3 files changed, 5 insertions, 6 deletions
diff --git a/drivers/staging/vt6656/card.h b/drivers/staging/vt6656/card.h
index 768515c2503d..d5f7c68c835d 100644
--- a/drivers/staging/vt6656/card.h
+++ b/drivers/staging/vt6656/card.h
@@ -55,8 +55,7 @@ void vnt_adjust_tsf(struct vnt_private *, u8, u64, u64);
bool vnt_get_current_tsf(struct vnt_private *, u64 *);
bool vnt_clear_current_tsf(struct vnt_private *);
void vnt_reset_next_tbtt(struct vnt_private *, u16);
-void CARDvUpdateNextTBTT(struct vnt_private *pDevice, u64 qwTSF,
- u16 wBeaconInterval);
+void vnt_update_next_tbtt(struct vnt_private *, u64, u16);
u64 vnt_get_next_tbtt(u64, u16);
u64 vnt_get_tsf_offset(u8 byRxRate, u64 qwTSF1, u64 qwTSF2);
int CARDbRadioPowerOff(struct vnt_private *pDevice);
diff --git a/drivers/staging/vt6656/wmgr.c b/drivers/staging/vt6656/wmgr.c
index 28112ec8314c..1646aafa774f 100644
--- a/drivers/staging/vt6656/wmgr.c
+++ b/drivers/staging/vt6656/wmgr.c
@@ -1917,7 +1917,7 @@ if(ChannelExceedZoneType(pDevice,byCurrChannel)==true)
MACvWriteBeaconInterval(pDevice, pMgmt->wCurrBeaconPeriod);
vnt_adjust_tsf(pDevice, pRxPacket->byRxRate, qwTimestamp, pRxPacket->qwLocalTSF);
- CARDvUpdateNextTBTT(pDevice, qwTimestamp, pMgmt->wCurrBeaconPeriod);
+ vnt_update_next_tbtt(pDevice, qwTimestamp, pMgmt->wCurrBeaconPeriod);
// Turn off bssid filter to avoid filter others adhoc station which bssid is different.
MACvWriteBSSIDAddress(pDevice, pMgmt->abyCurrBSSID);
@@ -1947,7 +1947,7 @@ if(ChannelExceedZoneType(pDevice,byCurrChannel)==true)
vnt_get_current_tsf(pDevice, &qwCurrTSF);
vnt_adjust_tsf(pDevice, pRxPacket->byRxRate, qwTimestamp , pRxPacket->qwLocalTSF);
vnt_get_current_tsf(pDevice, &qwCurrTSF);
- CARDvUpdateNextTBTT(pDevice, qwTimestamp, pMgmt->wCurrBeaconPeriod);
+ vnt_update_next_tbtt(pDevice, qwTimestamp, pMgmt->wCurrBeaconPeriod);
}
return;
diff --git a/drivers/staging/vt6656/card.c b/drivers/staging/vt6656/card.c
index 7cb7bbc69fd6..9ecf189021d5 100644
--- a/drivers/staging/vt6656/card.c
+++ b/drivers/staging/vt6656/card.c
@@ -32,7 +32,7 @@
* vnt_get_current_tsf - Read Current NIC TSF counter
* vnt_get_next_tbtt - Calculate Next Beacon TSF counter
* vnt_reset_next_tbtt - Set NIC Beacon time
* CARDvUpdateNextTBTT - Sync. NIC Beacon time
* CARDbRadioPowerOff - Turn Off NIC Radio Power
* CARDbRadioPowerOn - Turn On NIC Radio Power
* CARDbSetWEPMode - Set NIC Wep mode
@@ -728,7 +728,7 @@ void vnt_reset_next_tbtt(struct vnt_private *priv, u16 beacon_interval)
* Return Value: none
*
*/
-void CARDvUpdateNextTBTT(struct vnt_private *priv, u64 tsf,
+void vnt_update_next_tbtt(struct vnt_private *priv, u64 tsf,
u16 beacon_interval)
{
u8 data[8];
@@ -32,7 +32,7 @@
* vnt_get_next_tbtt - Calculate Next Beacon TSF counter
* vnt_reset_next_tbtt - Set NIC Beacon time
- * CARDvUpdateNextTBTT - Sync. NIC Beacon time
+ * vnt_update_next_tbtt - Sync. NIC Beacon time
* CARDbRadioPowerOff - Turn Off NIC Radio Power
* CARDbRadioPowerOn - Turn On NIC Radio Power